@@ -60,25 +60,24 @@ def authorize(required_roles: List[str], decission_logic: str = 'all'):
   :rtype: func
   """
 
-  def abort(context: ServicerContext):
-    details = f"Given roles don't intersect with {required_roles} using decission logic '{decission_logic}'"
-    logging.warn(f'403 Forbidden: {details}')
-    context.abort(StatusCode.PERMISSION_DENIED, details)
-
   def wrap(func):
     if not asyncio.iscoroutinefunction(func):
       def wrapped_func(self, request, context, *args, **kwargs):
         if (is_authorized(context, required_roles, decission_logic)):
           return func(self, request, context, *args, **kwargs)
         else:
-          abort(context)
+          details = f"Given roles don't intersect with {required_roles} using decission logic '{decission_logic}'"
+          logging.warn(f'403 Forbidden: {details}')
+          context.abort(StatusCode.PERMISSION_DENIED, details)
       return wrapped_func
     else:
       async def wrapped_func(self, request, context, *args, **kwargs):
         if (is_authorized(context, required_roles, decission_logic)):
           return await func(self, request, context, *args, **kwargs)
         else:
-          abort(context)
+          details = f"Given roles don't intersect with {required_roles} using decission logic '{decission_logic}'"
+          logging.warn(f'403 Forbidden: {details}')
+          await context.abort(StatusCode.PERMISSION_DENIED, details)
       return wrapped_func
 
   return wrap
