@@ -5,6 +5,16 @@ from grpc.aio import ServicerContext
 
 
 def get_user(context: ServicerContext) -> Dict:
+  """
+  Get x-delphai-user information.
+
+  :param grpc.aio.ServicerContext context: context passed to grpc endpoints
+  :raises: KeyError
+  :return x-delphai-user dictionary.
+    More information: https://wiki.delphai.dev/wiki/Authorization
+  :rtype: Dict
+  """
+
   metadata = dict(context.invocation_metadata())
   user64 = metadata['x-delphai-user']
   user = b64decode(user64)
@@ -16,12 +26,17 @@ def get_groups(context: ServicerContext) -> List[str]:
   Gets groups of calling identity
 
   :param grpc.aio.ServicerContext context: context passed to grpc endpoints
-  :return raw roles passed from keycloak
+  :return raw roles passed from keycloak.
+    For example this can be ["/delphai/Development"]
   :rtype List[str]
   """
+
   assert isinstance(context, object)
-  user = get_user(context)
-  return user['groups']
+  try:
+    user = get_user(context)
+  except KeyError:
+    return []
+  return user.get('groups') or []
 
 
 def get_affiliation(context: ServicerContext) -> Union[Tuple[str, str], None]:
